## Unreleased

- Restructure the routes into modules.
- Add pytest suite to API, utils, and main routes in the app.
- Add coverage analysis to pytest routines.
- Add coverage report to GitHub workflows.
- Add circle plot for appointment status.
